==> haskell-temporary-1.3-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-EBkpBwV0HPi1MEfbokVTnS
key:                  temporary-1.3-EBkpBwV0HPi1MEfbokVTnS
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  01d0079edeb3ef936b571e0a9b6186dd
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-8.10.2/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/temporary-1.3
hs-libraries:         HStemporary-1.3-EBkpBwV0HPi1MEfbokVTnS
depends:
    base-4.14.1.0 directory-1.3.6.0 exceptions-0.10.4 filepath-1.4.2.1
    random-1.2.0-KmddqukiyI6GX7qyfi2GyH transformers-0.5.6.2
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.3-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-CMfrQz1mx3sGC0xKashA4M
key:                  temporary-1.3-CMfrQz1mx3sGC0xKashA4M
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  d63faff012fe9589d84805a89abaa695
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-8.10.2/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/temporary-1.3
hs-libraries:         HStemporary-1.3-CMfrQz1mx3sGC0xKashA4M
depends:
    base-4.14.1.0 directory-1.3.6.0 exceptions-0.10.4 filepath-1.4.2.1
    random-1.2.0-ArkgnsvKZOJCInyIxwD8ha transformers-0.5.6.2
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
